@@ -14,3 +14,13 @@ CCPAGES_IMAGE_SIZES = getattr(
             (240,160),
             (480,320),
             (960,640)))
+
+"""Path to the custom layouts"""
+try:
+    layouts = settings.TEMPLATE_DIRS[0] + 'ccpages/layouts/'
+except IndexError:
+    layouts = None
+CUSTOM_LAYOUTS = getattr(
+        settings,
+        'CCPAGES_CUSTOM_LAYOUTS',
+        layouts)
